summaryrefslogtreecommitdiffstats
path: root/Source/WebCore/platform/graphics/android/BaseTile.h
diff options
context:
space:
mode:
Diffstat (limited to 'Source/WebCore/platform/graphics/android/BaseTile.h')
-rw-r--r--Source/WebCore/platform/graphics/android/BaseTile.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/Source/WebCore/platform/graphics/android/BaseTile.h b/Source/WebCore/platform/graphics/android/BaseTile.h
index ed06332..6ba66ef 100644
--- a/Source/WebCore/platform/graphics/android/BaseTile.h
+++ b/Source/WebCore/platform/graphics/android/BaseTile.h
@@ -54,7 +54,7 @@ class GLWebViewState;
* the BaseLayer's most recent PictureSet to a bitmap which is then uploaded
* to the GPU.
* 3. After the bitmap is uploaded to the GPU the main GL thread then uses the
* tile's draw() function to display the tile to the screen.
* 4. Steps 2-3 are repeated as necessary.
* 5. The tile is destroyed when the user navigates to a new page.
*
@@ -101,7 +101,8 @@ public:
bool isTileReady();
- void draw(float transparency, SkRect& rect, float scale);
+ void drawGL(float opacity, const SkRect& rect, float scale,
+ const TransformationMatrix* transform);
// the only thread-safe function called by the background thread
void paintBitmap();
@@ -54,7 +54,7 @@ class GLWebViewState;
* to the GPU.
* 3. After the bitmap is uploaded to the GPU the main GL thread then uses the
- * tile's draw() function to display the tile to the screen.
+ * tile's drawGL() function to display the tile to the screen.
* 4. Steps 2-3 are repeated as necessary.
* 5. The tile is destroyed when the user navigates to a new page.